%**************************************************************************
% This program solves for Case 2 (calibration, steady states and eigenvalues) 
% of the BSN paper by Dominguez & Gomis-Porqueras (2022)

% This program calls funqs.m 

clear all;
clc;
format long;

%**************************************************************************
% Parameter Values

global lomega chiid xiid byS PidS beta pitarget alpha0 alpha1 G gamma0 gamma1 gammaM0 gammaM1 etaM0 etaM1 btarget omega sigma chi xi zetaS zetaL;
beta   = 0.973483;  % discount factor
alpha1  = 1.50;     % slope of MP % TAYLOR PRINCIPLE alpha1>(1/beta)
pitarget=1.02;      %target inflation in region 0

%**************************************************************************
zetaS=1.0;           % pledgeability of short-term bonds
%zetaL;              % pledgeability of long-term bonds >> calibrated 
sigma = 1.00;        % frictions in DM
lomega =1;           % bargaining power 

%**************************************************************************
Go  = 0.21973;      % federal government expenditures to GDP as of 2014 Q4
botarget =0.718354; % public debt held domestically to GDP as of 2014 Q4
omega=2.352725714;  % proportion of long term debt relative to short-term bonds
omegatarget=omega;
bMotarget= 0.30; % target for bM - 30 per cent of GDP % Sensitivity >> 0.25 and 0.50
% These values will be modified to the units of the model

%**************************************************************************
% POLICY PARAMETERS
alpha0 = pitarget/beta; % alpha0 targets inflation in the steady state without premium
gamma1net = (1/beta)-1 + 0.0025;  % this is net of gammaM1
gammaM1=0.50;
% Additional policy parameters are set after the calibration is finalised

%**************************************************************************
                       % CALIBRATION
%**************************************************************************

%TIME SERIES of USA bonds, premia, inflation and output from 1985 to 2014
%(detrended and cleaned)

bS_0=textread('bondsS.txt','%n');
bL_0=textread('bondsL.txt','%n');
s_0=textread('premiumS.txt','%n'); % This is 20Y-3M
%sL_0=0*textread('premiumL.txt','%n'); % This is 20Y-1oY % if imposed that the repr long-term bond is illiquid
sL_0=textread('premiumL.txt','%n'); % This is 20Y-10Y
pii_0=textread('inflationPi.txt','%n');
y_0=textread('outputY.txt','%n');

nr=length(s_0); % length of the series
%**************************

% CALIBRATION: matching zetaL to the premia differential
meansS=mean(s_0);
meansL=mean(sL_0);
zetaL=zetaS*(meansL/meansS); % as the differential in premia btw long and short
%zetaL=0; % if imposed that the repr long-term bond is illiquid
%**************************

% CALIBRATION: matching xi and chi to the series on premia
ni=2001; %2001 
ximin=0.01;  ximax=0.99;  xii=linspace(ximin,ximax,ni); 

for xsi=1:ni;
for oo=1:nr;          
byx(oo) = (bS_0(oo)/y_0(oo))+(zetaL/zetaS)*(bL_0(oo)/y_0(oo));
qmaxito(xsi,oo)=byx(oo)/((pii_0(oo+1)/zetaS)*(lomega + (1-lomega)/(1-xii(xsi))) -(0.5*sigma*byx(oo)));
end; 
qmaxi(xsi)=max(qmaxito(xsi,:));
chii(xsi)= (qmaxi(xsi)^xii(xsi));
end;

X0=[0.5,0.02];   

for xsi=1:ni;  for oo=1:nr;          
byS= byx(oo);
PidS=pii_0(oo+1);
chiid=chii(xsi);
xiid=xii(xsi);

options=optimset('TolX',1e-8,'Display','off');
% Solving the equations:
[X1, eval, exitflag]=fsolve('funqs',X0,options); 

if exitflag ~=1 X1(1)=NaN; X1(2)=NaN; end; %disp ('Problem of convergence');  disp ('Exitflag'); disp (exitflag); end
%q(oo)=X1(1);
snew(xsi,oo) = X1(2);
shatnew(xsi,oo) = (zetaL/zetaS)*snew(xsi,oo);
SSError(xsi,oo)=((100*snew(xsi,oo))-s_0(oo))^2; %note that s multiplied by 100 so snew is multiplied by 100
SLError(xsi,oo)=((100*shatnew(xsi,oo))-sL_0(oo))^2; %note that s multiplied by 100 so snew is multiplied by 100
end; end; 

for xsi=1:ni; 
SSErroro(xsi,1)=SSError(xsi,1);
SLErroro(xsi,1)=SLError(xsi,1);
for noo=2:nr;
SSErroro(xsi,noo)=SSError(xsi,noo-1)+SSError(xsi,noo);
SLErroro(xsi,noo)=SLError(xsi,noo-1)+SLError(xsi,noo);
end;
MSSErrorr(xsi)=SSErroro(xsi,nr)/nr;
MSLErrorr(xsi)=SLErroro(xsi,nr)/nr;
TotalError(xsi)= MSSErrorr(xsi)+ MSLErrorr(xsi);
end;

MinTError = min(TotalError(:));
[xo] = find(TotalError == MinTError);

xi=xii(xo);
chi=chii(xo);
chiid=chi;
xiid=xi;

for oo=1:nr;          
byS= byx(oo);
PidS=pii_0(oo+1);

options=optimset('TolX',1e-8,'Display','off');
% Solving the equations:
[X1, eval, exitflag]=fsolve('funqs',X0,options); 

if exitflag ~=1 X1(1)=NaN; X1(2)=NaN; end; %disp ('Problem of convergence');  disp ('Exitflag'); disp (exitflag); end
qi(oo)=X1(1);
end; 

qmaxi=max(qi);
qmean=mean(qi);
markup= (1-lomega)*chi*(((chi)^-1)/(1-xi)) + lomega - 1; % This is the markup at satiation
meanmarkup= ((1-lomega)*chi*(((qmean)^-xi)/(1-xi)) + lomega - 1); % This is the mean markup
ymean = 1+ 0.5*sigma*qmean; % mean output

qmin=0;
qmax=chi^(1/xi);
umax=chi*((qmax^(1-xi))/(1-xi)) -qmax;

% CALIBRATION OF TARGETS
G=Go*ymean; % g to output
btarget=botarget*ymean; % b to output
bMtarget=bMotarget*ymean; % b to output
 
% POLICY PARAMETERS
gamma1net = (1/beta)-1 + 0.0025;  % this is net of gammaM1
gammaM0=(1-(1/beta))*bMtarget;
 
gammaM1=0.50;
gamma1= gamma1net*(1-gammaM1);
 
gamma0net= ((1-beta)/beta)*btarget + G; % this is net of gammaM0
gamma0= gamma0net-((1/beta)-1)*gammaM0;

%**************************************************************************
               % Rule on Maturity Composition of CB Bond Holdings
%**************************************************************************
n=81; %81 
m=81;

etaM1min=0.00;
etaM1max=2.00;
oMmin=0.00;
oMmax=3.0;

oMi=linspace(oMmin,oMmax,n);
etaM1i=linspace(etaM1min,etaM1max,m); %like alpha - oMi should be bMi

a1=zeros(n,m); g1=zeros(n,m); jac=zeros(n,m); jacs=zeros(n,m); jac2=zeros(n,m); 
nss=zeros(n,m); eig1=nan(n,m); eig2=nan(n,m); eig1o=nan(n,m); eig2o=nan(n,m);
pis=zeros(n,m); pi2s=zeros(n,m); bs=zeros(n,m); ss=zeros(n,m); udm=nan(n,m);
g1=zeros(n,m); g2=zeros(n,m); a1=zeros(n,m); a2=zeros(n,m);
gs1=nan(n,m); gs2=nan(n,m); gs3=nan(n,m); gs4=nan(n,m); gs5=nan(n,m); 
as1=nan(n,m); as2=nan(n,m); as3=nan(n,m); as4=nan(n,m); as5=nan(n,m);
asg=nan(n,m); gsg=nan(n,m); asl2=nan(n,m); gsl2=nan(n,m); asm2=nan(n,m); gsm2=nan(n,m);
gp1=nan(n,m); gn1=nan(n,m); go1=nan(n,m); go1=nan(n,m);
gp21=nan(n,m); gn21=nan(n,m); gpn1=nan(n,m);
ap21=nan(n,m); an21=nan(n,m); apn1=nan(n,m);ap1=nan(n,m); an1=nan(n,m);
udm=nan(n,m); 
au25=nan(n,m);  au50=nan(n,m);  au75=nan(n,m);  au10=nan(n,m); au20=nan(n,m); au30=nan(n,m);
gu25=nan(n,m);  gu50=nan(n,m);  gu75=nan(n,m);  gu10=nan(n,m); gu20=nan(n,m); gu30=nan(n,m);
a2u25=nan(n,m);  a2u50=nan(n,m);  a2u75=nan(n,m);  a2u10=nan(n,m); a2u20=nan(n,m); a2u30=nan(n,m);
g2u25=nan(n,m);  g2u50=nan(n,m);  g2u75=nan(n,m);  g2u10=nan(n,m); g2u20=nan(n,m); g2u30=nan(n,m);
ap1m=nan(n,m); gp1m=nan(n,m); an1l=nan(n,m); gn1l=nan(n,m);

for j1=1:n;
for j2=1:m;

omegaMtarget=oMi(j1);

etaM0=(bMtarget/(1+omegaMtarget));
etaM1=etaM1i(j2);
   
%**************************************************************************
                       % CHECKING STEADY STATES - MULTIPLICITY
%**************************************************************************
pomin = beta;
pomax= pitarget;

if ((beta*alpha1)<=0.999999999) 
    pomin= max(pitarget,pomin);
    pomax=3.0;
end;

nn = 301; %301
qo = linspace(qmin,qmax,nn);
  
for i = 2:nn;  

soS(i)= (0.5*sigma*zetaS)*((lomega*((chi*(qo(i)^(-xi)))-1))/(lomega+(1-lomega)*(chi*(qo(i)^(-xi)) ))); 

soL(i)= (zetaL/zetaS)*soS(i);

po(i) = pitarget + beta*(soS(i)/(1-beta*alpha1));
% This is consistent with Case 1 A, i.e. alpha2=alpha3=0.
% po(i)=pitarget; % would be consistent with alpha2=1.

bo(i)=(1/(gamma1 - ((1/beta)-1)*(1-gammaM1))) *(G - (gamma0+((1/beta)-1)*gammaM0) + (gamma1+((1/beta)-1)*gammaM1)*btarget - (soS(i)/zetaS)*((1-lomega)*chi*((qo(i)^(1-xi)))/(1-xi) + lomega*qo(i)));

helpzib(i)= ((1-etaM1)/(1+omega))*bo(i) - etaM0 + etaM1*(btarget/(1+omegatarget));
helpzibL(i)= (((omega+etaM1)/(1+omega))-gammaM1)*bo(i)+etaM0 - gammaM0 +(gammaM1 - (etaM1/(1+omegatarget)))*btarget;

qu(i)=((zetaS/(lomega*po(i)))*helpzib(i))+((zetaL/(lomega*po(i)))*helpzibL(i))- ((1-lomega)/lomega)*chi*((qo(i)^(1-xi))/(1-xi)); 

utdm(i)=(1/qo(i))*( (umax+qo(i))*((1-xi)/chi))^(1/(1-xi)) - 1;

qgraph(i)= qo(i)-qu(i);

helpi1(i)=  ((lomega*xi*chi*(qo(i)^(-xi-1)))/(lomega+(1-lomega)*chi*(qo(i)^(-xi)))^3); 
helpi2(i)= ((1-lomega)*chi*((qo(i)^(1-xi))/(1-xi))+lomega*qo(i));

partialsPi(i)= 0.5*sigma*(zetaS/po(i))*((helpi1(i)*helpi2(i)));
partialsLPi(i)= (zetaL/zetaS)*partialsPi(i);
partialsb(i)= -0.5*sigma*(zetaS/po(i))*( (helpi1(i)*(zetaS*((1-etaM1)/(1+omega)))+zetaL*(((omega+etaM1)/(1+omega))-gammaM1)));
partialsLb(i)=(zetaL/zetaS)*partialsb(i);
end; 

p1=0; b1=0; s1=0; s1L=0; eigen1=0; eigen2=0; jac22=0; udm1=0; udm1L=0;
    
for i = 3:nn; 

if (qgraph(i)*qgraph(i-1)) >= 0; psign(i)=0; else; psign(i)=1; end;
if po(i)<=pomin-0.000001; psign(i)=0; end; 
if po(i)>=pomax+0.000001; psign(i)=0; end; 

if psign(i)==1;
    
    s1=[s1,soS(i)]; s1L=[s1L,soL(i)]; p1=[p1,po(i)]; b1=[b1,bo(i)]; udm1=[udm1,utdm(i)]; 
   
f11 = -1+(beta*partialsPi(i)); 
f12 = beta*alpha1; 
f13 = beta*partialsb(i); 
f14 = 0;
 
% For case 1B we instead have ? f11=-1+(beta*partialsPi); f12 = beta*alpha1- beta*partialsPi; f13 = beta*partialsb; f14= beta*partialsb;
f21= 0;
f22= -( (partialsPi(i)*po(i)-soS(i))*helpzib(i)+(partialsLPi(i)*po(i)-soL(i))*helpzibL(i))*(1/((1-gammaM1)*(po(i)^2))); 
f23=-1;
f24=(1/beta)-(1/(1-gammaM1))*(gamma1 + partialsb(i)*(helpzib(i)/po(i)) + (soS(i)/po(i))*(1/(1+omega))*(1-etaM1) + partialsLb(i)*(helpzibL(i)/po(i)) + (soL(i)/po(i))*( ((omega+etaM1)/(1+omega)) - gammaM1)); 

asf = -(1/((f11*f23) - (f13*f21))); 
Jacob=zeros(2,2);
Jacob(1,1)= asf*((f12*f23)-(f13*f22)); 
Jacob(1,2)= asf*((f14*f23)-(f13*f24)); 
Jacob(2,1)= asf*(-(f12*f21)+(f11*f22)); 
Jacob(2,2)= asf*(-(f14*f21)+(f11*f24)); 

eigenB=eig(Jacob);
eigen1=[eigen1,eigenB(1)];
eigen2=[eigen2,eigenB(2)];
jac22=[jac22,Jacob(2,1)];
jac22max=max(abs(jac22));
end;
end;

pnumss = size(s1,2)-1; %sum(psign);
nss(j1,j2)=pnumss;

if pnumss>=1;
pis(j1,j2)=p1(2); 
bs(j1,j2)=b1(2); 
bstotarget(j1,j2)=b1(2)-btarget; 
ss(j1,j2)=s1(2);
udm(j1,j2)=udm1(2);
end;

if pnumss>=1;
eig1(j1,j2)=eigen1(2);
eig2(j1,j2)=eigen2(2);
end;

if pnumss>=2;
eig1o(j1,j2)=eigen1(3);
eig2o(j1,j2)=eigen2(3);
end;

if pnumss>=2;
pi2s(j1,j2)=p1(3); 
ud2m(j1,j2)=udm1(3);
ud2min(j1,j2)=min(udm1(2),udm1(3)); % change by max to have the graph with the highest welfare cost
end;

if pnumss==1; if udm(j1,j2)<=0.001;  gu25(j1,j2)=etaM1; au25(j1,j2)=omegaMtarget;  end; end;
if pnumss==1; if udm(j1,j2)>=0.00100001; if udm(j1,j2)<=0.002;   gu50(j1,j2)=etaM1; au50(j1,j2)=omegaMtarget;  end; end; end;
if pnumss==1; if udm(j1,j2)>=0.00200001; if udm(j1,j2)<=0.003;   gu75(j1,j2)=etaM1; au75(j1,j2)=omegaMtarget;  end; end; end;
if pnumss==1; if udm(j1,j2)>=0.00300001; if udm(j1,j2)<=0.010;   gu10(j1,j2)=etaM1; au10(j1,j2)=omegaMtarget;  end; end; end;
if pnumss==1; if udm(j1,j2)>=0.0100001;  if udm(j1,j2)<=0.100;   gu20(j1,j2)=etaM1; au20(j1,j2)=omegaMtarget;  end; end; end;
if pnumss==1; if udm(j1,j2)>=0.100001; gu30(j1,j2)=etaM1; au30(j1,j2)=omegaMtarget;  end; end;

if pnumss==2; if ud2min(j1,j2)<=0.001;  g2u25(j1,j2)=etaM1; a2u25(j1,j2)=omegaMtarget;  end; end;
if pnumss==2; if ud2min(j1,j2)>=0.00100001; if ud2min(j1,j2)<=0.002;   g2u50(j1,j2)=etaM1; a2u50(j1,j2)=omegaMtarget;  end; end; end;
if pnumss==2; if ud2min(j1,j2)>=0.00200001; if ud2min(j1,j2)<=0.003;   g2u75(j1,j2)=etaM1; a2u75(j1,j2)=omegaMtarget;  end; end; end;
if pnumss==2; if ud2min(j1,j2)>=0.00300001; if ud2min(j1,j2)<=0.010;   g2u10(j1,j2)=etaM1; a2u10(j1,j2)=omegaMtarget;  end; end; end;
if pnumss==2; if ud2min(j1,j2)>=0.01000001; if ud2min(j1,j2)<=0.100;   g2u20(j1,j2)=etaM1; a2u20(j1,j2)=omegaMtarget;  end; end; end;
if pnumss==2; if ud2min(j1,j2)>=0.100001; g2u30(j1,j2)=etaM1; a2u30(j1,j2)=omegaMtarget;  end; end;

if pnumss==1; g1(j1,j2)=etaM1; a1(j1,j2)=omegaMtarget; jac(j1,j2)=Jacob(2,1);  end;
if pnumss==2; g2(j1,j2)=etaM1; a2(j1,j2)=omegaMtarget; jac2(j1,j2)=jac22max; end;    

if pnumss==1; gs(j1,j2)=etaM1; as(j1,j2)=omegaMtarget; jacs(j1,j2)=Jacob(2,1);  end;
if pnumss==2; gs(j1,j2)=etaM1; as(j1,j2)=omegaMtarget; jacs(j1,j2)=jac22max; end;    

if pnumss==1;  if eigen1(2)>=1.0;  if eigen2(2)<=0.999999999999; stab(j1,j2)=1; gs1(j1,j2)=etaM1; as1(j1,j2)=omegaMtarget; end; end; end;
if pnumss==1;  if eigen2(2)>=1.0;  if eigen1(2)<=0.999999999999; stab(j1,j2)=1; gs1(j1,j2)=etaM1; as1(j1,j2)=omegaMtarget; end; end; end;
if pnumss==1;  if eigen1(2)<=0.99999999999999;  if eigen2(2)<=0.999999999999; stab(j1,j2)=2; gs2(j1,j2)=etaM1; as2(j1,j2)=omegaMtarget; end; end; end;
if pnumss==1;  if eigen1(2)>=1.0;  if eigen2(2)>=1.0; stab(j1,j2)=3; gs3(j1,j2)=etaM1; as3(j1,j2)=omegaMtarget; end; end; end;

if pnumss==1; if pis(j1,j2)>=1.01; gp1m(j1,j2)=etaM1; ap1m(j1,j2)=omegaMtarget; end;  end; 
if pnumss==1; if pis(j1,j2)>=1.0; if pis(j1,j2)<=1.00999999999; gp1(j1,j2)=etaM1; ap1(j1,j2)=omegaMtarget; end;  end; end;
%if pnumss==1; if pis(j1,j2)>=1.0; gp1(j1,j2)=etaM1; ap1(j1,j2)=omegaMtarget; end;  end; %end;
%if pnumss==1; if pis(j1,j2)<=0.999999999999; gn1(j1,j2)=etaM1; an1(j1,j2)=omegaMtarget; end; end;  %end;
if pnumss==1; if pis(j1,j2)<=0.999999999999; if pis(j1,j2)>=0.99; gn1(j1,j2)=etaM1; an1(j1,j2)=omegaMtarget; end; end;  end;
if pnumss==1; if pis(j1,j2)<=0.989999999999; gn1l(j1,j2)=etaM1; an1l(j1,j2)=omegaMtarget; end;  end;


if pnumss==1; if bstotarget(j1,j2)>=0.00; gpb(j1,j2)=etaM1; apb(j1,j2)=omegaMtarget; end;  end; 
if pnumss==1; if bstotarget(j1,j2)<=-0.000000001; gnb(j1,j2)=etaM1; anb(j1,j2)=omegaMtarget; end;  end; 

if pnumss==2; if pis(j1,j2)>=1.0; if pi2s(j1,j2)>=1.0; gp21(j1,j2)=etaM1; ap21(j1,j2)=omegaMtarget; end;  end; end;
if pnumss==2; if pis(j1,j2)>=1.0; if pi2s(j1,j2)<=0.9999999999; gpn1(j1,j2)=etaM1; apn1(j1,j2)=omegaMtarget; end;  end; end;
if pnumss==2; if pis(j1,j2)<=0.999999999999; if pi2s(j1,j2)<=0.9999999999; gn21(j1,j2)=etaM1; an21(j1,j2)=omegaMtarget; end;  end; end;
if pnumss==2; if pis(j1,j2)<=0.999999999999; if pi2s(j1,j2)>=1.0; gpn1(j1,j2)=etaM1; apn1(j1,j2)=omegaMtarget; end;  end; end;
    
if pnumss==2;  if eigen1(2)>=1.0;  if eigen2(2)<=0.999999999999; stab(j1,j2)=1; gs4(j1,j2)=etaM1; as4(j1,j2)=omegaMtarget; end; end; end;
if pnumss==2;  if eigen2(2)>=1.0;  if eigen1(2)<=0.999999999999; stab(j1,j2)=1; gs4(j1,j2)=etaM1; as4(j1,j2)=omegaMtarget; end; end; end;
if pnumss==2;  if eigen1(3)>=1.0;  if eigen2(3)<=0.999999999999; stab(j1,j2)=1; gs4(j1,j2)=etaM1; as4(j1,j2)=omegaMtarget; end; end; end;
if pnumss==2;  if eigen2(3)>=1.0;  if eigen1(3)<=0.999999999999; stab(j1,j2)=1; gs4(j1,j2)=etaM1; as4(j1,j2)=omegaMtarget; end; end; end;

if pnumss==2;  if eigen1(2)>=1.0;  if eigen2(2)>=1.0; if eigen1(3)>=1.0;  if eigen2(3)>=1.0;  stab(j1,j2)=3; gs5(j1,j2)=etaM1; as5(j1,j2)=omegaMtarget; end; end; end; end; end;
if pnumss==2;  if eigen1(2)>=1.0;  if eigen2(2)>=1.0;  if eigen1(3)<=0.99999999;  if eigen2(3)<=0.9999999999; stab(j1,j2)=3; gs5(j1,j2)=etaM1; as5(j1,j2)=omegaMtarget; end; end; end;  end; end;
if pnumss==2;  if eigen1(3)>=1.0;  if eigen2(3)>=1.0;  if eigen1(2)<=0.99999999;  if eigen2(2)<=0.9999999999;  stab(j1,j2)=3; gs5(j1,j2)=etaM1; as5(j1,j2)=omegaMtarget; end; end; end;  end; end;
if pnumss==2;  if eigen1(3)<=0.99999999;  if eigen2(3)<=0.9999999999; if eigen1(2)<=0.99999999;  if eigen2(2)<=0.9999999999;     stab(j1,j2)=3; gs5(j1,j2)=etaM1; as5(j1,j2)=omegaMtarget; end; end; end;  end; end;
end;
end;

eig0(1)=beta*alpha1;
eig0(2)= (1/beta) - gamma1net;
eigmin1(1)=min(min(eig1));
eigmin1(2)=min(min(eig2));
eigmax1(1)=max(max(eig1));
eigmax1(2)=max(max(eig2));

if pnumss>1.001;
eigmin1o(1)=min(min(eig1o));
eigmin1o(2)=min(min(eig2o));
eigmax1o(1)=max(max(eig1o));
eigmax1o(2)=max(max(eig2o));
eigmin1(1)=min(eigmin1(1),eigmin1o(1));
eigmin1(2)=min(eigmin1(2),eigmin1o(2));
eigmax1(1)=max(eigmax1(1),eigmax1o(1));
eigmax1(2)=max(eigmax1(2),eigmax1o(2));
end;

figure(1);
plot(as1,gs1,'bo',as2,gs2,'ro',as3,gs3,'ro',as4,gs4,'kx',as5,gs5,'rx');
axis([oMmin oMmax etaM1min etaM1max]);
ylabel('\eta^M_1 ');
xlabel('\Omega^M target');
%ht = text(1.5, 1.8, {'{\color{blue} o } Unique stable steady state', '{\color{red} o } Unique unstable steady state','{\color{black} x } Two steady states: one stable, one unstable'}, 'EdgeColor', 'k'); % pitarget change
ht = text(1.85, 1.8, {'{\color{blue} o } Unique stable steady state', '{\color{red} o } Unique unstable steady state'}, 'EdgeColor', 'k'); % pitarget change

figure(2);
plot(au25,gu25,'ko',au50,gu50,'bo',au75,gu75,'mo',au10,gu10,'ro',a2u25,g2u25,'kx');
%plot(au25,gu25,'ko',au50,gu50,'bo',au75,gu75,'mo',au10,gu10,'ro',a2u10,g2u10,'rx');
axis([oMmin oMmax etaM1min etaM1max]);
ylabel('\eta^M_1 ');
xlabel('\Omega^M target');
ht = text(1.85, 1.75, {'{\color{black} o,x } less than 0.1 per cent', '{\color{blue} o,x} btw 0.1 and 0.2 per cent',  '{\color{magenta} o,x } btw 0.1 and 0.3 per cent', '{\color{red} o,x } btw 0.3 and 1 per cent'}, 'EdgeColor', 'k'); % pitarget change

figure(3);
plot(an1l,gn1l,'bo',an1,gn1,'co',ap1,gp1,'mo',ap1m,gp1m,'ro');
axis([oMmin oMmax etaM1min etaM1max]);
ylabel('\eta^M_1 ');
xlabel('\Omega^M target');
%ht = text(1.7, 1.75, {'{\color{cyan} o } Negative Inflation Rate', '{\color{magenta} o } Positive Inflation Rate','{\color{blue} x } 2 Negative Inflation Rates','{\color{red} x } 2 Positive Inflation Rates','{\color{green} x } 1 Positive/1 Negative Inflation Rates'}, 'EdgeColor', 'k');
ht = text(1.85, 1.75, {'{\color{blue} o } Inflation Rate below - 1 %', '{\color{cyan} o } Inflation Rate btw -1 and 0 %', '{\color{magenta} o }  Inflation Rate btw 0 and 1 %','{\color{red} 0 } Inflation Rates btw 1 and 2 %'}, 'EdgeColor', 'k');


figure(2);
plot(au25,gu25,'ko',au50,gu50,'bo',au75,gu75,'mo',au10,gu10,'ro',au20,gu20,'go',au30,gu30,'yo',a2u25,g2u25,'kx',a2u50,g2u50,'bx',a2u75,g2u75,'mx',a2u10,g2u10,'rx',a2u20,g2u20,'gx');
%plot(au25,gu25,'ko',au50,gu50,'bo',au75,gu75,'mo',au10,gu10,'ro',a2u10,g2u10,'rx');
axis([oMmin oMmax etaM1min etaM1max]);
ylabel('\eta^M_1 ');
xlabel('\Omega^M target');
ht = text(1.85, 1.7, {'{\color{black} o,x } less than 0.1 per cent', '{\color{blue} o,x} btw 0.1 and 0.2 per cent',  '{\color{magenta} o,x } btw 0.1 and 0.3 per cent', '{\color{red} o,x } btw 0.3 and 1 per cent','{\color{green} o,x} btw 1 and 10 per cent'}, 'EdgeColor', 'k'); % pitarget change

%**************************************************************************
                       % RESULTS
%**************************************************************************
disp('  ');
disp('============================================');
disp('              PARAMETERS');
disp('============================================');
disp(sprintf('  Calibrated beta:      %g', beta));
disp(sprintf('  Calibrated xi:        %g', xi));
disp(sprintf('  Calibrated chi:       %g', chi));
disp(sprintf('  etaS:                  %g', zetaS));
disp(sprintf('  etaL:                  %g', zetaL));
disp(sprintf('  sigma:                %g', sigma));
disp(sprintf('  lomega:                %g', lomega));
disp(sprintf('  Mean implied markup:  %g', meanmarkup));
disp(sprintf('  Mean implied output:  %g', ymean));
disp('============================================');
disp('              SOME TARGETS');
disp('============================================');
disp(sprintf('  pitarget:              %g', pitarget));
disp('============================================');
disp('              POLICY PARAMETERS');
disp('============================================');
disp(sprintf('  G:                      %g', G));
disp(sprintf('  Calibrated alpha0:      %g', alpha0));
disp(sprintf('  alpha1:                 %g', alpha1));
disp(sprintf('  Calibrated gamma0:      %g', gamma0));
disp(sprintf('  gamma1:                 %g', gamma1));
disp(sprintf('  gammaM0:                %g', gammaM0));
disp(sprintf('  gammaM1:                %g', gammaM1));
disp(sprintf('  etaM0:                  %g', etaM0));
disp(sprintf('  etaM1:                  %g', etaM1));
disp(sprintf('  b target:               %g', btarget));
disp(sprintf('  omega:                  %g', omega));
disp(sprintf('  bM target:              %g', bMtarget));
disp('============================================');
disp('      EIGENVALUES WITH AND WITHOUT PREMIUM');
disp('============================================');
disp(sprintf('  No premium:    %g      %g', eig0));
disp(sprintf('  Minimum:       %g      %g', eigmin1));
disp(sprintf('  Maximum:       %g      %g', eigmax1));
disp(sprintf('  Difference:    %g      %g', eigmax1-eigmin1));
disp('============================================');
disp(sprintf('  Difference:    %g      %g', eigmax1-eig0));
disp('============================================');

